@@ -84,11 +84,12 @@ class WebHook(object):
     def fail(self, reason):
         self.completed = time.time()
         self.status = STATUS_FAILED
+        self.application.enqueue(self.application.process)
 
     def done(self):
         self.completed = time.time()
         self.status = STATUS_OK
-        self.application.enqueue(self.application.next)
+        self.application.enqueue(self.application.process)
 
     def wait_subprocess(self):
         pid, status = os.waitpid(self.subprocess.pid, os.WNOHANG)
@@ -190,7 +191,7 @@ class Handler(tornado.web.RequestHandler):
 
     def post(self):
         try:
-            hook = WebHook(self.application, self.request)
+            hook = WebHook.create(self.application, self.request)
             if hook:
                 self.application.queue.append(hook)
                 self.application.done.append(hook)
